@@ -177,14 +177,7 @@ static void RGB24_BLT(VncBaseFramebufferPrivate *priv,
         guint8 *sp = src;
 
         for (i = 0; i < width; i++) {
-            /*
-             * We use priv->remoteFormat->XXX_shift instead of usual priv->Xls
-             * because the source pixel component is a full 8 bits in
-             * size, and so doesn't need the adjusted shift
-             */
-            *dp = (((sp[0] * priv->remoteFormat->red_max) / 255) << priv->remoteFormat->red_shift) |
-                (((sp[1] * priv->remoteFormat->green_max) / 255) << priv->remoteFormat->green_shift) |
-                (((sp[2] * priv->remoteFormat->blue_max) / 255) << priv->remoteFormat->blue_shift);
+            *dp = (sp[0] << 16 | sp[1] << 8 | sp[2]);
             dp++;
             sp += 3;
         }
@@ -213,11 +206,3 @@ static void RGB24_BLT(VncBaseFramebufferPrivate *priv,
 #undef SUFFIX
 #undef SPLICE
 #undef SPLICE_I
-
-/*
- * Local variables:
- *  c-indent-level: 4
- *  c-basic-offset: 4
- *  indent-tabs-mode: nil
- * End:
- */
