@@ -134,6 +134,7 @@ VncGrabSequence *vnc_grab_sequence_copy(VncGrabSequence *sequence)
  */
 void vnc_grab_sequence_free(VncGrabSequence *sequence)
 {
+    g_free(sequence->keysyms);
     g_slice_free(VncGrabSequence, sequence);
 }
 
@@ -178,12 +179,3 @@ guint vnc_grab_sequence_get_nth(VncGrabSequence *sequence,
 
     return sequence->keysyms[n];
 }
-
-
-/*
- * Local variables:
- *  c-indent-level: 4
- *  c-basic-offset: 4
- *  indent-tabs-mode: nil
- * End:
- */
